<?php
/**
 * @file
 * The class handling display and recording sanitization.
 *
 * @copyright (c) 2005-2013 Ouest Systemes Informatiques (OSInet)
 *
 * @license Licensed under the General Public License version 2 or later.
 */

namespace Drupal\zeitgeist;

/**
 * Point of sanitization.
 */
class Sanitization extends Enum {
  /**
   * @const Do not perform search sanitization.
   */
  const NO = 0;

  /**
   * @const Sanitize on recording.
   */
  const RECORD = 1;

  /**
   * @const Sanitize on display (Drupal default approach).
   */
  const DISPLAY = 2;

  /**
   * @const Default validation type is to validate upon display.
   */
  const DEFVALIDATION = Sanitization::DISPLAY;

  /**
   * @const Name of configuration variable for handling of HTML search strings.
   */
  const VARVALIDATION = 'zeitgeist_validation';

  /**
   * Checks whether the search passes validation (anti-spam).
   *
   * @param string $keys
   *   The search query.
   * @param string $stage
   *   save | view
   *
   * @return bool
   *   Validation result.
   */
  public static function validate($keys, $stage) {
    $option = variable_get(Sanitization::VARVALIDATION, Sanitization::DEFVALIDATION);
    $html = ($keys != strip_tags($keys));
    $ret = TRUE;

    switch ($stage) {
      case 'save':
        if ($html && $option == Sanitization::RECORD) {
          $ret = FALSE;
        }
        break;

      case 'view':
        if ($html && $option == Sanitization::DISPLAY) {
          $ret = FALSE;
        }
        break;

      default:
        $ret = TRUE;
    }
    return $ret;
  }

  /**
   * Return the currently configured sanitization type.
   *
   * @return int
   *   self::NO|self::RECORD|self::DISPLAY
   */
  public static function getValidationType() {
    return variable_get(Sanitization::VARVALIDATION, Sanitization::DEFVALIDATION);
  }
}
