<?php
/**
 * @file
 * The class handling search records for Zeitgeist.
 *
 * @copyright (c) 2005-2013 Ouest Systemes Informatiques (OSInet)
 *
 * @license Licensed under the General Public License version 2 or later.
 */


namespace Drupal\zeitgeist;

/**
 * Zeitgeist search records.
 */
class Search {
  /**
   * Stores a search.
   *
   * @param string $keys
   *   The search query.
   * @param string $kind
   *   The search type.
   * @param int $timestamp
   *   The search submission timestamp.
   */
  public static function store($keys, $kind, $timestamp = NULL) {
    // Make sure we do want to store an empty search.
    $do_store = empty($keys) ? variable_get(ZGVARRECORDEMPTY, ZGDEFRECORDEMPTY) : TRUE;

    if (!$do_store || !Sanitization::validate($keys, 'save')) {
      return;
    }

    if (!isset($timestamp)) {
      $timestamp = REQUEST_TIME;
    }

    $search = (object) array(
      'search'   => $keys,
      'category' => $kind,
      'ts'       => $timestamp,
    );

    drupal_write_record('zeitgeist', $search);
    // Since we added a new record, block contents may have changed.
    Cache::clearAll();
  }
}
